@@ -22,6 +22,9 @@ class APIFunction(LambdaFunction):
         elif method == "put":
             response = self.put(event, *args)
 
+        elif method == "options":
+            response = self.create_return()
+
         else:
             raise Exception(f"Triggered with unexpected HTTP method {method}.")
 
