@@ -35,10 +35,17 @@ class Deployer(object):
                 )
         return env_vars
 
+    def _install_reqs(self):
+        reqs = os.path.abspath(f"{self.dir}/requirements.txt")
+        subprocess.run(["pip", "install", "-r", reqs], check=True)
+
     def _build_template(self, output_dir=None):
         # Checking custom output directory.
         output_file = f"{output_dir}/bld.yml" if output_dir else "bld.yml"
 
+        # Installing requirements so everything is importable.
+        self._install_reqs()
+
         # Running files to create subclasses.
         # TODO: Change these from hardcoded to dynamic.
         exec(open("function.py").read())
@@ -125,7 +132,7 @@ class Deployer(object):
         s3.create_bucket(
             ACL="private", Bucket=f"{self.project_name}-{self.environment}"
         )
-
+        self._build()
         env_vars = self._get_env_vars()
         overrides = [
             f"ParameterKey={x['alpha_name']},ParameterValue={x['value']}"
